[![Tests](https://github.com/trafire/promail/workflows/Tests/badge.svg)](https://github.com/trafire/promail/actions?workflow=Tests)
[![Codecov](https://codecov.io/gh/trafire/promail/branch/master/graph/badge.svg)](https://codecov.io/gh/trafire/promail)
[![PyPI](https://img.shields.io/pypi/v/hypermodern-python.svg)](https://pypi.org/project/hypermodern-python/)
# promail

Email Templates:

 When you install we create an email templates file with installed templates commented out. You can enable any templates by uncommenting these.

Email Templates:
    Composed of fragments
    Should include a json that explains format of the data and a description and a sample. We should also see if we can include a jpeg screen print of the sample data (maybe using playwright to render html and take a screen shot https://stackoverflow.com/questions/60598837/html-to-image-using-python)
